@@ -42,12 +42,12 @@ _VIEWCODE_CACHE: Dict[str, Tuple[str, Dict]] = {}
 """Caches a module's parse results for use in viewcode."""
 
 
-class RemovedInAutoAPI2Warning(DeprecationWarning):
-    """Indicates something that will be removed in sphinx-autoapi v2."""
+class RemovedInAutoAPI3Warning(DeprecationWarning):
+    """Indicates something that will be removed in sphinx-autoapi v3."""
 
 
 if "PYTHONWARNINGS" not in os.environ:
-    warnings.filterwarnings("default", category=RemovedInAutoAPI2Warning)
+    warnings.filterwarnings("default", category=RemovedInAutoAPI3Warning)
 
 
 def _normalise_autoapi_dirs(autoapi_dirs, srcdir):
@@ -65,15 +65,20 @@ def _normalise_autoapi_dirs(autoapi_dirs, srcdir):
 
 
 def run_autoapi(app):  # pylint: disable=too-many-branches
-    """
-    Load AutoAPI data from the filesystem.
-    """
+    """Load AutoAPI data from the filesystem."""
     if app.config.autoapi_type not in LANGUAGE_MAPPERS:
         allowed = ", ".join(f'"{api_type}"' for api_type in sorted(LANGUAGE_MAPPERS))
         raise ExtensionError(
             f"Invalid autoapi_type setting, following values are allowed: {allowed}"
         )
 
+    if app.config.autoapi_type != "python":
+        warnings.warn(
+            "Support for documenting languages other than Python "
+            "will be removed in AutoAPI v3.",
+            RemovedInAutoAPI3Warning,
+        )
+
     if not app.config.autoapi_dirs:
         raise ExtensionError("You must configure an autoapi_dirs setting")
 
@@ -81,7 +86,7 @@ def run_autoapi(app):  # pylint: disable=too-many-branches
         warnings.warn(
             "autoapi_include_summaries has been replaced by "
             "the show-module-summary AutoAPI option\n",
-            RemovedInAutoAPI2Warning,
+            RemovedInAutoAPI3Warning,
         )
         if app.config.autoapi_include_summaries:
             app.config.autoapi_options.append("show-module-summary")
@@ -123,7 +128,7 @@ def run_autoapi(app):  # pylint: disable=too-many-branches
                 "autoapi_template_dir will be expected to be "
                 "relative to the Sphinx source directory instead of "
                 "relative to where sphinx-build is run\n",
-                RemovedInAutoAPI2Warning,
+                RemovedInAutoAPI3Warning,
             )
     sphinx_mapper_obj = sphinx_mapper(app, template_dir=template_dir, url_root=url_root)
 
@@ -178,9 +183,7 @@ def source_read(app, docname, source):  # pylint: disable=unused-argument
 
 
 def doctree_read(app, doctree):
-    """
-    Inject AutoAPI into the TOC Tree dynamically.
-    """
+    """Inject AutoAPI into the TOC Tree dynamically."""
 
     if app.env.docname == "index":
         all_docs = set()
@@ -204,8 +207,8 @@ def doctree_read(app, doctree):
                 insert = False
         if insert and app.config.autoapi_add_toctree_entry:
             # Insert AutoAPI index
-            nodes[-1]["entries"].append((None, f"{app.config.autoapi_root}/index"))
-            nodes[-1]["includefiles"].append(f"{app.config.autoapi_root}/index")
+            nodes[-1]["entries"].append((None, toc_entry))
+            nodes[-1]["includefiles"].append(toc_entry)
             message_prefix = colorize("bold", "[AutoAPI] ")
             message = colorize(
                 "darkgreen", f"Adding AutoAPI TOCTree [{toc_entry}] to index.rst"
@@ -261,7 +264,13 @@ def viewcode_follow_imported(app, modname, attribute):
     if fullname not in all_objects:
         return None
 
-    orig_path = all_objects[fullname].obj.get("original_path", "")
+    if all_objects[fullname].obj.get("type") == "method":
+        fullname = fullname[: fullname.rfind(".")]
+        attribute = attribute[: attribute.rfind(".")]
+    while all_objects[fullname].obj.get("original_path", "") != "":
+        fullname = all_objects[fullname].obj.get("original_path")
+
+    orig_path = fullname
     if orig_path.endswith(attribute):
         return orig_path[: -len(attribute) - 1]
 
@@ -271,7 +280,10 @@ def viewcode_follow_imported(app, modname, attribute):
 def setup(app):
     app.connect("builder-inited", run_autoapi)
     app.connect("source-read", source_read)
-    app.connect("doctree-read", doctree_read)
+    # Use a lower priority than the default to ensure that we can
+    # inject into the toctree before Sphinx tries to use it
+    # in another doctree-read transformer.
+    app.connect("doctree-read", doctree_read, priority=400)
     app.connect("build-finished", build_finished)
     if "viewcode-find-source" in app.events.events:
         app.connect("viewcode-find-source", viewcode_find)
